==> Heinzelmann-7.19.003-PHP8.zip: Quellcode/legacy/modules/start/locales/en.php <==
<?php

$__LANG['Anzahl'] = 'Count';
$__LANG['Aufrufe'] = 'Calls';
$__LANG['Aufwand'] = 'Expense';
$__LANG['Es sind keine Supporter anwesend'] = 'No Supporter online';
$__LANG['Fenster schlie&szlig;en'] = 'Close window';
$__LANG['Geschrieben von'] = 'Written from';
$__LANG['Keine Knowledgebaseeintr&auml;ge vorhanden'] = 'No Knowledgebase entries';
$__LANG['Knowledgebase - Die f&uuml;nf neuesten Artikel'] = 'Knowledgebase - Latest (5)';
$__LANG['Knowledgebase - TOP 10'] = 'Knowledgebase - TOP 10';
$__LANG['Kurzbeschreibung'] = 'Ticket title';
$__LANG['Neues Fenster'] = 'New window';
$__LANG['Neues Ticket'] = 'New Ticket';
$__LANG['Priorit&auml;t'] = 'Priority';
$__LANG['Shoutbox'] = 'Shoutbox';
$__LANG['Status'] = 'Status';
$__LANG['Supporter-Online'] = 'Supporter-Online';
$__LANG['Ticket'] = 'Ticket';
$__LANG['Ticket&uuml;bersicht (Gesamt)'] = 'Overview (Total)';
$__LANG['Ticket&uuml;bersicht (Nur Eigene)'] = 'Overview (Own)';
$__LANG['weiterlesen...'] = 'read more...';
$__LANG['zur&uuml;ck...'] = 'back...';
$__LANG['FCSBEGR_2'] = '<span style="font-weight: bold;">HEINZELM<span style="color: rgb(255, 0, 0);">A</span>NN</span> Service.Desk: More transparency for helpdesk and support.<br />All trouble tickets and service requests from employees and customers are <br />recorded centrally within one relational data base.<br>With HEINZELMANN, you lay the foundation of a long-lasting helpdesk efficiency <br />and little support effort by maintaining structured data and an integrated <br />knowledge base.';
$__LANG['FCSBEGR_1'] = 'Welcome to HEINZELMANN Service.Desk';
$__LANG['Links'] = 'Links';
$__LANG['Standardansicht wiederherstellen'] = 'Restore default view';
$__LANG['Keine Links definiert'] = 'No links defined';
$__LANG['gewählt'] = 'selected';
$__LANG['Nicht angezeite Objete'] = 'Not displayed objects';
$__LANG['Ticket&uuml;bersicht'] = 'Ticket overview';
$__LANG['Nur Eigene'] = 'Just own';
$__LANG['Gesamt'] = 'Total';
$__LANG['TOP 10'] = 'TOP 10';
$__LANG['Die f&uuml;nf neuesten Artikel'] = 'The five latest articles';
$__LANG['Detailreport'] = 'Detail report';
$__LANG['Detailierter Report über WFs und deren Formulardaten'] = 'Detailed report on WFs and their form data';
$__LANG['je Schlagwort'] = 'per tag';
$__LANG['je LDAP Ger?t'] = 'per LDAP device';
$__LANG['Service'] = 'Service';
$__LANG['Servicekatalog'] = 'Service catalog';
$__LANG['Servicetypen Liste'] = 'Service Type List';
$__LANG['Neuen Servicelevel anlegen'] = 'Create a new service level';
$__LANG['Servicelevel Liste'] = 'Service Level List';
$__LANG['Oberfl?chen Einstellungen'] = 'GUI Settings';
$__LANG['Mehr...'] = 'More ...';
$__LANG['Services'] = 'Services';
$__LANG['Service Contracts (SLAs)'] = 'Service Contracts (SLAs)';
$__LANG['SLAs'] = 'SLAs';
$__LANG['Suche nach TicketID öffnet das Ticket, wenn dieses sichtbar ist.'] = 'Search for TicketID opens the ticket when it is visible.';
$__LANG['Neue Version verfügbar'] = 'New version available';
$__LANG['Download'] = 'Download';
$__LANG['verw. Heinzelmann-Verzeichnis'] = 'used Heinzelmann directory';
$__LANG['Shoutbox in separaten Fenster öffnen'] = 'Open Shoutbox in separate window';
$__LANG['Standardansicht wiederherstellen'] = 'Restore default view';
$__LANG['Laden...'] = 'Loading...';
$__LANG['Senden'] = 'Send';
$__LANG['Ziehen Sie Elemente, die nicht angezeigt werden sollen in dieses Panel.'] = 'Drag items that you do not want to be displayed into this panel.';
$__LANG['Durch den Reset-Button können Sie die Standardansicht wieder herstellen'] = 'The reset button allows you to restore the default view.';
$__LANG['Nicht angezeigte Objekte'] = 'Not displayed objects';
$__LANG['Durch den Reset-Button können Sie die Standardansicht wieder herstellen.'] = 'The reset button allows you to restore the default view.';
$__LANG['Bewegen Sie das Objekt an die gewünschte Stelle'] = 'Move the object to the desired position.';
$__LANG['Shoutbox in separaten Fenster öffnen'] = 'Open Shoutbox in separate window';

$__LANG['Reset'] = 'Reset';
$__LANG['Anzahl der Tickets nach Status'] = 'Number of tickets by status';
$__LANG['Anzahl der Tickets nach Priorität'] = 'Number of tickets by priority';
$__LANG['Aufwand zur Ticketbearbeitung, nach Status (in Minuten)'] = 'Effort for ticket processing, by status (in minutes)';
$__LANG['Aufwand zur Ticketbearbeitung, nach Priorität (in Minuten)'] = 'Effort for ticket processing, by priority (in minutes)';

$__LANG['nach Status'] = 'by status';
$__LANG['nach Priorität'] = 'by priority';
$__LANG['Ihre Nachricht'] = 'Your message';

$__LANG['Tickets gesamt'] = 'Tickets total';
$__LANG['Keine Tickets vorhanden'] = 'No tickets available';
$__LANG['Die f&uuml;nf neusten Artikel'] = 'The five latest articles';
$__LANG['Anzahl von Tickets'] = 'Number of tickets';
$__LANG['Aufwand zur Bearbeitung von Tickets (in Minuten)'] = 'Effort for editing tickets (in minutes)';
$__LANG['Anzahl von Tickets (Gesamt)'] = 'Number of tickets (total)';
$__LANG['Die aktuelle Heinzelmann-Version kann nicht ermittelt werden.'] = 'The current Heinzelmann version cannot be determined';
$__LANG['Prüfen Sie ggf. das Update-Verzeichnis manuell'] = 'If necessary, check the update directory manually';
$__LANG['Verwendete Version'] = 'Version used';
$__LANG['Installationsverzeichnis'] = 'Installation directory';
$__LANG['Stand'] = 'Status';

$__LANG['ChangeLog'] = 'ChangeLog';
$__LANG['Ticketliste'] = 'Ticket list';
$__LANG['Bitte wählen Sie ein Filter'] = 'Please select a filter';
$__LANG['Ticketlist'] = 'Ticket list';
$__LANG['eigene'] = 'own';
$__LANG['Ticketübersicht – Status'] = 'Ticket overview - status';

$__LANG['Eintrag _START_ bis _END_ (von _TOTAL_)'] = 'Entry _START_ to _END_ (of _TOTAL_)';
$__LANG['Eintrag _START_ bis _END_ (von _TOTAL_)'] = 'Entry _START_ to _END_ (of _TOTAL_)';

$__LANG['Frag den Bot'] = 'Ask bot';
$__LANG['Asset'] = 'Asset';
$__LANG['Titel'] = 'Title';
$__LANG['Gerätetyp'] = 'Device type';
$__LANG['Niederlassung'] = 'Branch';
$__LANG['Zeige _MENU_ Eintr&auml;ge'] = 'Show entries MENU';
$__LANG['Keine Eintr&auml;ge gefunden'] = 'No entries found';
$__LANG[' - gefiltert aus _MAX_ Eintr&auml;gen'] = '-filtered from _MAX_ entries';

==> Heinzelmann-7.20.001-PHP8.zip: Quellcode/legacy/modules/start/locales/en.php <==
<?php

$__LANG['Anzahl'] = 'Count';
$__LANG['Aufrufe'] = 'Calls';
$__LANG['Aufwand'] = 'Expense';
$__LANG['Es sind keine Supporter anwesend'] = 'No Supporter online';
$__LANG['Fenster schlie&szlig;en'] = 'Close window';
$__LANG['Geschrieben von'] = 'Written from';
$__LANG['Keine Knowledgebaseeintr&auml;ge vorhanden'] = 'No Knowledgebase entries';
$__LANG['Knowledgebase - Die f&uuml;nf neuesten Artikel'] = 'Knowledgebase - Latest (5)';
$__LANG['Knowledgebase - TOP 10'] = 'Knowledgebase - TOP 10';
$__LANG['Kurzbeschreibung'] = 'Ticket title';
$__LANG['Neues Fenster'] = 'New window';
$__LANG['Neues Ticket'] = 'New Ticket';
$__LANG['Priorit&auml;t'] = 'Priority';
$__LANG['Shoutbox'] = 'Shoutbox';
$__LANG['Status'] = 'Status';
$__LANG['Supporter-Online'] = 'Supporter-Online';
$__LANG['Ticket'] = 'Ticket';
$__LANG['Ticket&uuml;bersicht (Gesamt)'] = 'Overview (Total)';
$__LANG['Ticket&uuml;bersicht (Nur Eigene)'] = 'Overview (Own)';
$__LANG['weiterlesen...'] = 'read more...';
$__LANG['zur&uuml;ck...'] = 'back...';
$__LANG['FCSBEGR_2'] = '<span style="font-weight: bold;">HEINZELM<span style="color: rgb(255, 0, 0);">A</span>NN</span> Service.Desk: More transparency for helpdesk and support.<br />All trouble tickets and service requests from employees and customers are <br />recorded centrally within one relational data base.<br>With HEINZELMANN, you lay the foundation of a long-lasting helpdesk efficiency <br />and little support effort by maintaining structured data and an integrated <br />knowledge base.';
$__LANG['FCSBEGR_1'] = 'Welcome to HEINZELMANN Service.Desk';
$__LANG['Links'] = 'Links';
$__LANG['Standardansicht wiederherstellen'] = 'Restore default view';
$__LANG['Keine Links definiert'] = 'No links defined';
$__LANG['gewählt'] = 'selected';
$__LANG['Nicht angezeite Objete'] = 'Not displayed objects';
$__LANG['Ticket&uuml;bersicht'] = 'Ticket overview';
$__LANG['Nur Eigene'] = 'Just own';
$__LANG['Gesamt'] = 'Total';
$__LANG['TOP 10'] = 'TOP 10';
$__LANG['Die f&uuml;nf neuesten Artikel'] = 'The five latest articles';
$__LANG['Detailreport'] = 'Detail report';
$__LANG['Detailierter Report über WFs und deren Formulardaten'] = 'Detailed report on WFs and their form data';
$__LANG['je Schlagwort'] = 'per tag';
$__LANG['je LDAP Ger?t'] = 'per LDAP device';
$__LANG['Service'] = 'Service';
$__LANG['Servicekatalog'] = 'Service catalog';
$__LANG['Servicetypen Liste'] = 'Service Type List';
$__LANG['Neuen Servicelevel anlegen'] = 'Create a new service level';
$__LANG['Servicelevel Liste'] = 'Service Level List';
$__LANG['Oberfl?chen Einstellungen'] = 'GUI Settings';
$__LANG['Mehr...'] = 'More ...';
$__LANG['Services'] = 'Services';
$__LANG['Service Contracts (SLAs)'] = 'Service Contracts (SLAs)';
$__LANG['SLAs'] = 'SLAs';
$__LANG['Suche nach TicketID öffnet das Ticket, wenn dieses sichtbar ist.'] = 'Search for TicketID opens the ticket when it is visible.';
$__LANG['Neue Version verfügbar'] = 'New version available';
$__LANG['Download'] = 'Download';
$__LANG['verw. Heinzelmann-Verzeichnis'] = 'used Heinzelmann directory';
$__LANG['Shoutbox in separaten Fenster öffnen'] = 'Open Shoutbox in separate window';
$__LANG['Standardansicht wiederherstellen'] = 'Restore default view';
$__LANG['Laden...'] = 'Loading...';
$__LANG['Senden'] = 'Send';
$__LANG['Ziehen Sie Elemente, die nicht angezeigt werden sollen in dieses Panel.'] = 'Drag items that you do not want to be displayed into this panel.';
$__LANG['Durch den Reset-Button können Sie die Standardansicht wieder herstellen'] = 'The reset button allows you to restore the default view.';
$__LANG['Nicht angezeigte Objekte'] = 'Not displayed objects';
$__LANG['Durch den Reset-Button können Sie die Standardansicht wieder herstellen.'] = 'The reset button allows you to restore the default view.';
$__LANG['Bewegen Sie das Objekt an die gewünschte Stelle'] = 'Move the object to the desired position.';
$__LANG['Shoutbox in separaten Fenster öffnen'] = 'Open Shoutbox in separate window';

$__LANG['Reset'] = 'Reset';
$__LANG['Anzahl der Tickets nach Status'] = 'Number of tickets by status';
$__LANG['Anzahl der Tickets nach Priorität'] = 'Number of tickets by priority';
$__LANG['Aufwand zur Ticketbearbeitung, nach Status (in Minuten)'] = 'Effort for ticket processing, by status (in minutes)';
$__LANG['Aufwand zur Ticketbearbeitung, nach Priorität (in Minuten)'] = 'Effort for ticket processing, by priority (in minutes)';

$__LANG['nach Status'] = 'by status';
$__LANG['nach Priorität'] = 'by priority';
$__LANG['Ihre Nachricht'] = 'Your message';

$__LANG['Tickets gesamt'] = 'Tickets total';
$__LANG['Keine Tickets vorhanden'] = 'No tickets available';
$__LANG['Die f&uuml;nf neusten Artikel'] = 'The five latest articles';
$__LANG['Anzahl von Tickets'] = 'Number of tickets';
$__LANG['Aufwand zur Bearbeitung von Tickets (in Minuten)'] = 'Effort for editing tickets (in minutes)';
$__LANG['Anzahl von Tickets (Gesamt)'] = 'Number of tickets (total)';
$__LANG['Die aktuelle Heinzelmann-Version kann nicht ermittelt werden.'] = 'The current Heinzelmann version cannot be determined';
$__LANG['Prüfen Sie ggf. das Update-Verzeichnis manuell'] = 'If necessary, check the update directory manually';
$__LANG['Verwendete Version'] = 'Version used';
$__LANG['Installationsverzeichnis'] = 'Installation directory';
$__LANG['Stand'] = 'Status';

$__LANG['ChangeLog'] = 'ChangeLog';
$__LANG['Ticketliste'] = 'Ticket list';
$__LANG['Bitte wählen Sie ein Filter'] = 'Please select a filter';
$__LANG['Ticketlist'] = 'Ticket list';
$__LANG['eigene'] = 'own';
$__LANG['Ticketübersicht – Status'] = 'Ticket overview - status';

$__LANG['Eintrag _START_ bis _END_ (von _TOTAL_)'] = 'Entry _START_ to _END_ (of _TOTAL_)';
$__LANG['Eintrag _START_ bis _END_ (von _TOTAL_)'] = 'Entry _START_ to _END_ (of _TOTAL_)';

$__LANG['Frag den Bot'] = 'Ask bot';
$__LANG['Asset'] = 'Asset';
$__LANG['Titel'] = 'Title';
$__LANG['Gerätetyp'] = 'Device type';
$__LANG['Niederlassung'] = 'Branch';
$__LANG['Zeige _MENU_ Eintr&auml;ge'] = 'Show entries MENU';
$__LANG['Keine Eintr&auml;ge gefunden'] = 'No entries found';
$__LANG[' - gefiltert aus _MAX_ Eintr&auml;gen'] = '-filtered from _MAX_ entries';

$__LANG['Im gleichen Fenster öffnen'] = 'Open in the same window';
$__LANG['Im neuen Tab öffnen'] = 'Open in a new tab';
